pub struct KillWait { /* private fields */ }Expand description
Used to wait for signal handler to be triggered.
Implementations
Sourceimpl KillWait
impl KillWait
Sourcepub fn wait(self)
pub fn wait(self)
Wait for a signal to terminate the signal handler.
Panics
If the signal handler returns an error this function will panic.
Examples found in repository?
examples/wait.rs (line 22)
3fn main() {
4 //
5 // Initialize signal handler
6 //
7 let kw = simple_sigh::init().unwrap();
8
9 //
10 // Set a signal handler callback
11 //
12 #[allow(clippy::significant_drop_tightening)]
13 simple_sigh::register(move |_| {
14 println!("Received signal");
15 })
16 .unwrap();
17
18 //
19 // Wait until abort
20 //
21 println!("Wait for interrupt/termination signal..");
22 kw.wait();
23 println!("Bye!");
24}Auto Trait Implementations
impl Freeze for KillWait
impl !RefUnwindSafe for KillWait
impl Send for KillWait
impl Sync for KillWait
impl Unpin for KillWait
impl !UnwindSafe for KillWait